package extras

// ProductCode of predefined products
type ProductCode string

// String implementation
func (c ProductCode) String() string {
	return string(c)
}

// Predefined product codes
const (
	ProductLandlordListingFee             ProductCode = "landlord_listing_fee"
	ProductLandlordExtraListing           ProductCode = "landlord_extra_listing"
	ProductLandlordEPCCertificate         ProductCode = "landlord_epc_certificate"
	ProductLandlordGasCertificate         ProductCode = "landlord_gas_certificate"
	ProductLandlordGasSafetyBoilerService ProductCode = "landlord_gas_safety_boiler_service"
	ProductLandlordEICReport              ProductCode = "landlord_eic_report"
	ProductLandlordPhotographsFloorPlan   ProductCode = "landlord_photographs_floor_plans"
	ProductLandlordHomeEmergencyInsurance ProductCode = "landlord_home_emergency_insurance"
	ProductLandlordRentGuaranteeInsurance ProductCode = "landlord_rent_guarantee_insurance"
	ProductLandlordLegalExpensesInsurance ProductCode = "landlord_legal_expenses_insurance"
	ProductLandlordInventory              ProductCode = "landlord_inventory"
	ProductLandlordInventoryCheckIn       ProductCode = "landlord_inventory_check_in"
	ProductLandlordInventoryCheckOut      ProductCode = "landlord_check_out"
	ProductTenantContentInsurance         ProductCode = "tenant_content_insurance"
	ProductContentInsurance               ProductCode = "content_insurance"
	ProductLandlordReferencingCheck       ProductCode = "landlord_referencing_check"
	ProductTenantReferencing              ProductCode = "tenant_referencing"
	ProductLandlordRentPayout             ProductCode = "landlord_rent_payout"
	ProductLandlordRentPayoutFee          ProductCode = "landlord_rent_payout_fee"
	ProductLandlordAdvancePayout          ProductCode = "landlord_advance_payout"
	ProductLandlordAdvancePayoutFee       ProductCode = "landlord_advance_payout_fee"
	ProductManagerViewingPayout           ProductCode = "manager_viewing_payout"
	ProductTenantHoldingDeposit           ProductCode = "tenant_holding_deposit"
	ProductTenantStandingOrder            ProductCode = "tenant_standing_order"
	ProductTenantFirstMonthRent           ProductCode = "tenant_first_month_rent"
	ProductTenantDepositReplacement       ProductCode = "tenant_deposit_replacement"
	ProductTenantTenancyClaimSettlement   ProductCode = "tenancy_claim_settlement"
	ProductLandlordBuildingInsurance      ProductCode = "landlord_building_insurance"
	ProductLandlordLifeInsurance          ProductCode = "landlord_life_insurance"
	// ProductTenantDeposit unused, merged with ProductTenantFirstMonthRent
	ProductTenantDeposit                       ProductCode = "tenant_deposit"
	ProductLandlordInventoryUnfurnished        ProductCode = "landlord_inventory_unfurnished"          // disabled
	ProductLandlordInventoryFurnished          ProductCode = "landlord_inventory_furnished"            // disabled
	ProductLandlordInventoryCheckInFurnished   ProductCode = "landlord_inventory_check_in_furnished"   // disabled
	ProductLandlordInventoryCheckInUnfurnished ProductCode = "landlord_inventory_check_in_unfurnished" // disabled
)

// KnownProductCodes that cannot be changed by user
var KnownProductCodes = []ProductCode{
	ProductLandlordListingFee,
	ProductLandlordExtraListing,
	ProductLandlordEPCCertificate,
	ProductLandlordGasCertificate,
	ProductLandlordGasSafetyBoilerService,
	ProductLandlordEICReport,
	ProductLandlordPhotographsFloorPlan,
	ProductLandlordHomeEmergencyInsurance,
	ProductLandlordRentGuaranteeInsurance,
	ProductLandlordLegalExpensesInsurance,
	ProductLandlordInventory,
	ProductLandlordInventoryCheckIn,
	ProductLandlordInventoryCheckOut,
	ProductTenantContentInsurance,
	ProductLandlordReferencingCheck,
	ProductLandlordRentPayout,
	ProductLandlordAdvancePayout,
	ProductManagerViewingPayout,
	ProductTenantHoldingDeposit,
	ProductTenantStandingOrder,
	ProductTenantFirstMonthRent,
	ProductTenantDepositReplacement,
	ProductTenantTenancyClaimSettlement,
	ProductTenantDeposit,
	ProductLandlordInventoryUnfurnished,
	ProductLandlordInventoryFurnished,
	ProductLandlordInventoryCheckInFurnished,
	ProductLandlordInventoryCheckInUnfurnished,
}

// ProviderCode of predefined providers
type ProviderCode string

// String implementation
func (c ProviderCode) String() string {
	return string(c)
}

// Predefined provider codes
const (
	ProviderUnknown ProviderCode = ""
	ProviderMuuv    ProviderCode = "muuv"
)
