//go:generate mockgen -package=mock -destination=mock/repository.go . Repository

// Package model provides model abstraction for extras service
package model

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"
	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

// ServicesListOptions parameters for extra's services list query
type ServicesListOptions struct {
	Attribute   *extras.Attribute
	Role        extras.ServiceRole
	Type        extras.ServiceType
	CartProduct bool
}

// Repository provides persistent operations for extras service
type Repository interface {
	Migrate(ctx context.Context) error
	ServiceGetByID(ctx context.Context, id primitive.ObjectID) (*Service, error)
	ServiceGetByCode(ctx context.Context, code string) (*Service, error)
	ServiceExistsByID(ctx context.Context, id primitive.ObjectID) (bool, error)
	ServiceExistsByCode(ctx context.Context, code string) (bool, error)
	ServiceCreate(ctx context.Context, service *Service) error
	ServiceUpdate(ctx context.Context, service *Service) error
	ServiceRemove(ctx context.Context, id primitive.ObjectID) error
	ServicesList(ctx context.Context, options *ServicesListOptions) ([]*Service, error)
	ServicesFilter(ctx context.Context, filter *query.QueryParams) ([]*Service, int64, error)
}
