// Package v13 provides migration for mongo repository
package v13

import (
	"context"

	extras "gitlab.mashroom.com/mashroom/backend/extras/api"

	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/bson/primitive"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	cur, err := col.Find(ctx, bson.M{"attributes": bson.M{"$ne": nil}})
	if err != nil {
		return -1, err
	}

	var res []struct {
		Attributes map[int32]string   `bson:"attributes"`
		ID         primitive.ObjectID `bson:"_id,omitempty"`
	}

	err = cur.All(ctx, &res)
	if err != nil {
		return -1, err
	}

	for _, r := range res {
		if len(r.Attributes) == 0 {
			continue
		}

		_, err = col.UpdateOne(ctx, bson.M{"_id": r.ID}, bson.M{
			"$set": bson.M{
				"attributes": map[extras.AttributeCode]string{
					extras.AttributeVibrant: r.Attributes[1],
				},
			},
		})
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
