// Package v14 provides migration for mongo repository
package v14

import (
	"context"

	"go.mongodb.org/mongo-driver/bson"

	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	mapping := map[string][]string{
		"certificate": {
			"landlord_eic_report",
			"landlord_gas_certificate",
			"landlord_epc_certificate",
		},
		"home_emergency_insurance": {
			"landlord_home_emergency_insurance",
		},
		"inventory": {
			"landlord_inventory",
			"landlord_inventory_furnished",
			"landlord_inventory_unfurnished",
		},
		"check_in_report": {
			"landlord_inventory_check_in",
			"landlord_inventory_check_in_furnished",
			"landlord_inventory_check_in_unfurnished",
		},
		"check_out_report": {
			"landlord_check_out",
		},
		"photo": {
			"landlord_photographs_floor_plans",
		},
		"referencing_report": {
			"landlord_referencing_check",
			"tenant-referencing",
		},
		"rent_guarantee_insurance": {
			"landlord_rent_guarantee_insurance",
		},
		"contents_insurance": {
			"content_insurance",
		},
	}

	_, err := col.UpdateMany(ctx, bson.M{"attributes": nil}, bson.M{"$set": bson.M{"attributes": bson.M{}}})
	if err != nil {
		return -1, err
	}

	for k, vs := range mapping {
		_, err := col.UpdateMany(
			ctx,
			bson.M{"code": bson.M{"$in": vs}},
			bson.M{"$set": bson.M{"attributes.document_type": k}},
		)
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
