// Package v15 provides migration for mongo repository
package v15

import (
	"context"

	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	mapping := map[string][]string{
		"12": {
			"landlord_home_emergency_insurance",
			"landlord_rent_guarantee_insurance",
			"content_insurance",
			"landlord_gas_certificate",
		},
		"60": {
			"landlord_epc_certificate",
		},
		"120": {
			"landlord_eic_report",
		},
	}

	_, err := col.UpdateMany(ctx, bson.M{"attributes": nil}, bson.M{"$set": bson.M{"attributes": bson.M{}}})
	if err != nil {
		return -1, err
	}

	for k, vs := range mapping {
		_, err = col.UpdateMany(
			ctx,
			bson.M{"code": bson.M{"$in": vs}},
			bson.M{"$set": bson.M{"attributes.document_validity_months": k}},
		)
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
