// Package v21 provides migration for mongo repository
package v21

import (
	"context"
	"time"

	"go.mongodb.org/mongo-driver/mongo/options"

	"go.mongodb.org/mongo-driver/bson"

	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/model"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	_, err := col.ReplaceOne(
		ctx,
		bson.M{
			"code": extras.ProductLandlordLegalExpensesInsurance.String(),
		},
		&model.Service{
			Attributes: map[extras.AttributeCode]string{
				"document_type":            "legal_expenses_insurance",
				"document_validity_months": "12",
			},
			Created: time.Now(),
			Updated: time.Now(),
			Code:    extras.ProductLandlordLegalExpensesInsurance.String(),
			Title:   "Legal Expenses Insurance",
			Description: "Landlord Legal Expenses insurance provides cover for legal expenses in claims such as " +
				"tenant disputes, pursuit of rent arrears and tenant eviction.",
			Type:             extras.ServiceType_LEGAL_EXPENSES_INSURANCE,
			Role:             extras.ServiceRole_LANDLORD_INSURANCE,
			Status:           extras.ServiceStatus_ACTIVE,
			TaxType:          extras.TaxType_TAX_TYPE_IPT,
			Price:            35.41,
			TaxAmount:        3.59,
			TaxPercentage:    12,
			InventoryCode:    "5",
			InventoryAccount: "205.2",
		},
		options.Replace().SetUpsert(true),
	)
	if err != nil {
		return -1, err
	}

	return -1, nil
}
