// Package v22 provides migration for mongo repository
package v22

import (
	"context"

	"go.mongodb.org/mongo-driver/bson"

	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (res int, err error) {
	col := db.Collection("extras")

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"landlord_referencing_check",
			"tenant_referencing",
			"tenant-referencing"}}},
		bson.M{"$set": bson.M{"inventory_code": "MP01"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"landlord_check_out",
			"landlord_inventory_check_out"}}},
		bson.M{"$set": bson.M{"inventory_code": "MP02"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_gas_certificate"},
		bson.M{"$set": bson.M{"inventory_code": "MP03.1"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_gas_safety_boiler_service"},
		bson.M{"$set": bson.M{"inventory_code": "MP03.2"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_inventory_check_in"},
		bson.M{"$set": bson.M{"inventory_code": "MP04"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_rent_guarantee_insurance"},
		bson.M{"$set": bson.M{"inventory_code": "MP05"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_home_emergency_insurance"},
		bson.M{"$set": bson.M{"inventory_code": "MP06"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_photographs_floor_plans"},
		bson.M{"$set": bson.M{"inventory_code": "MP07"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_epc_certificate"},
		bson.M{"$set": bson.M{"inventory_code": "MP08"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"first_month_deposit_replacement",
			"deposit_replacement",
			"scheduled_deposit_replacement",
			"deposit-replacement-landlord",
			"tenant_deposit_replacement",
			"deposit_replacement_fee",
			"tenant_first_month_deposit_replacement",
			"deposit_replacement_fee_vat"}}},
		bson.M{"$set": bson.M{"inventory_code": "MP09"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_eic_report"},
		bson.M{"$set": bson.M{"inventory_code": "MP10"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "contents-insurance"},
		bson.M{"$set": bson.M{"inventory_code": "MP11"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_inventory"},
		bson.M{"$set": bson.M{"inventory_code": "MP12"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "tenancy_claim_settlement"},
		bson.M{"$set": bson.M{"inventory_code": "MP13"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "manager_viewing_payout"},
		bson.M{"$set": bson.M{"inventory_code": "MRO14"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "tenant_deposit"},
		bson.M{"$set": bson.M{"inventory_code": "MRI15"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "first-time-buyer"},
		bson.M{"$set": bson.M{"inventory_code": "MP16"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_extra_listing"},
		bson.M{"$set": bson.M{"inventory_code": "MP17"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_building_insurance"},
		bson.M{"$set": bson.M{"inventory_code": "MI23"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_legal_expenses_insurance"},
		bson.M{"$set": bson.M{"inventory_code": "MI24"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_listing_fee"},
		bson.M{"$set": bson.M{"inventory_code": "MP25"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"tenant_content_insurance",
			"content_insurance"}}},
		bson.M{"$set": bson.M{"inventory_code": "MI26"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"buy-to-let",
			"remortgage"}}},
		bson.M{"$set": bson.M{"inventory_code": "MP27"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "tenant_first_month_rent"},
		bson.M{"$set": bson.M{"inventory_code": "MRI28"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "tenant_holding_deposit"},
		bson.M{"$set": bson.M{"inventory_code": "MRI29"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "tenant_standing_order"},
		bson.M{"$set": bson.M{"inventory_code": "MRI30"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateMany(ctx,
		bson.M{"code": bson.M{"$in": bson.A{
			"landlord_rent_payout",
			"rent-payout"}}},
		bson.M{"$set": bson.M{"inventory_code": "MRO31"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_rent_payout_fee"},
		bson.M{"$set": bson.M{"inventory_code": "MRO32"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_advance_payout"},
		bson.M{"$set": bson.M{"inventory_code": "MRO33"}})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx,
		bson.M{"code": "landlord_advance_payout_fee"},
		bson.M{"$set": bson.M{"inventory_code": "MRO34"}})
	if err != nil {
		return -1, err
	}

	return -1, nil
}
