// Package v8 provides migration for mongo repository
package v8

import (
	"context"

	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up adds service data into extras collection
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	data := [][2]bson.M{
		{
			bson.M{
				"code": "landlord_referencing_check",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "1",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_epc_certificate",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "8",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_gas_certificate",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "3",
				"inventory_offset":  1,
			},
		},
		{
			bson.M{
				"code": "tenant_deposit_replacement",
			},
			bson.M{
				"inventory_account": "205",
				"inventory_code":    "9",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_check_out",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "2",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_photographs_floor_plans",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "7",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_home_emergency_insurance",
			},
			bson.M{
				"inventory_account": "205.1",
				"inventory_code":    "6",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_inventory",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "12",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_inventory_check_in",
			},
			bson.M{
				"inventory_account": "207",
				"inventory_code":    "4",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "content_insurance",
			},
			bson.M{
				"inventory_account": "205.3",
				"inventory_code":    "11",
				"inventory_offset":  0,
			},
		},
		{
			bson.M{
				"code": "landlord_rent_guarantee_insurance",
			},
			bson.M{
				"inventory_account": "205.2",
				"inventory_code":    "5",
				"inventory_offset":  0,
			},
		},
	}

	for _, d := range data {
		_, err := col.UpdateOne(ctx, d[0], bson.M{"$set": d[1]})
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
