// Package v9 provides migration for mongo repository
package v9

import (
	"context"

	extras "gitlab.mashroom.com/mashroom/backend/extras/api"

	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up adds service data into extras collection
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	data := [][2]bson.M{
		{
			bson.M{
				"code": "landlord_epc_certificate",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "EPC",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_check_out",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Check-out {{.BedroomsNo}}bed",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_inventory_check_in_furnished",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Furnished Inventory and check-in {{.BedroomsNo}}bed",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_inventory_check_in_unfurnished",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Unfurnished Inventory and check-in {{.BedroomsNo}}bed",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_inventory_check_in",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "{{.FurnishedState}} Inventory and check-in {{.BedroomsNo}}bed",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_gas_certificate",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Gas Safety Certificate",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_eic_report",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Electrical Installation Condition Report (EICR)",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_photographs_floor_plans",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Professional photographs and Floor plans",
				},
			},
		},
		{
			bson.M{
				"code": "landlord_home_emergency_insurance",
			},
			bson.M{
				"attributes": map[extras.AttributeType]string{
					extras.AttributeType_ATTRIBUTE_TYPE_VIBRANT: "Home Emergency Insurance",
				},
			},
		},
	}

	for _, d := range data {
		_, err := col.UpdateOne(ctx, d[0], bson.M{"$set": d[1]})
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
