// Package service provides implementation for extras service
package service

import (
	"context"
	"fmt"

	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/model"
	offer "gitlab.mashroom.com/mashroom/backend/offer/api"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
)

// Connections remote service connections
type Connections struct {
	Property property.PropertyServiceClient
	Offer    offer.OfferServiceClient
}

// Config for service implementation
type Config struct {
	// Persistent repository
	Repository model.Repository
	// Connections services connections
	Connections Connections
}

// Service implementation
type Service interface {
	extras.ExtrasServiceServer
}

func validateConfig(config *Config) error {
	if config == nil {
		return fmt.Errorf("invalid service config")
	}

	if config.Repository == nil {
		return fmt.Errorf("no repository in service config")
	}

	if config.Connections.Property == nil {
		return fmt.Errorf("no connection for property client in service config")
	}

	if config.Connections.Offer == nil {
		return fmt.Errorf("no connection for offer client in service config")
	}

	return nil
}

// NewService returns new service instance
func NewService(ctx context.Context, config *Config) (Service, error) {
	err := validateConfig(config)
	if err != nil {
		return nil, err
	}

	srv := &serviceImpl{
		config: *config,
	}

	return srv, nil
}
