package test

import (
	"github.com/golang/mock/gomock"
	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/model"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func (s *serviceSuite) TestExtrasDelete_ok() {
	m := extras.DeleteRequest{
		Id: primitive.NewObjectID().Hex(),
	}
	obj, _ := primitive.ObjectIDFromHex(m.Id)

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		Code: "hello",
	}, nil)
	s.repo.EXPECT().ServiceRemove(s.testCtx, obj)

	resp, err := s.srv.Delete(s.testCtx, &m)

	s.Require().NoError(err)

	s.Require().Equal(resp.Success, true)
}

func (s *serviceSuite) TestExtrasDelete_errCodeExist() {
	m := extras.DeleteRequest{
		Id: primitive.NewObjectID().Hex(),
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		Code: extras.ProductLandlordListingFee.String(),
	}, nil)

	resp, err := s.srv.Delete(s.testCtx, &m)

	s.Require().Errorf(err, "predefined codes cannot be changed or removed")

	s.Require().Nil(resp)
}
