package test

import (
	"github.com/golang/mock/gomock"
	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/model"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func (s *serviceSuite) TestExtrasGet_ok() {
	m := &extras.GetRequest{
		Id: primitive.NewObjectID().Hex(),
		Property: &extras.Property{
			Id:     "",
			Rental: &property.PropertyRental{},
			Conditions: &extras.Conditions{
				Price: 100,
			},
		},
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		PriceNeedCalculate: true,
		Type:               extras.ServiceType_RENT_GUARANTEE_INSURANCE,
	}, nil)

	res, err := s.srv.Get(s.testCtx, m)

	s.Require().NoError(err)

	s.Require().NotEmpty(res)
}

func (s *serviceSuite) TestExtrasGet_ok2() {
	m := &extras.GetRequest{
		Id: primitive.NewObjectID().Hex(),
		Property: &extras.Property{
			Id:     "",
			Rental: &property.PropertyRental{},
			Conditions: &extras.Conditions{
				Price: 100,
			},
			Details: &property.PropertyDetails{
				AmenityFurniture: property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED,
			},
		},
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		PriceNeedCalculate: true,
		Type:               extras.ServiceType_INVENTORY_REPORT,
	}, nil)

	res, err := s.srv.Get(s.testCtx, m)

	s.Require().NoError(err)

	s.Require().NotEmpty(res)
}

func (s *serviceSuite) TestExtrasGet_ok3() {
	m := &extras.GetRequest{
		Id: primitive.NewObjectID().Hex(),
		Property: &extras.Property{
			Id:     "",
			Rental: &property.PropertyRental{},
			Conditions: &extras.Conditions{
				Price: 100,
			},
			Details: &property.PropertyDetails{
				AmenityFurniture: property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED,
			},
		},
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		PriceNeedCalculate: true,
		Type:               extras.ServiceType_DEPOSIT,
	}, nil)

	res, err := s.srv.Get(s.testCtx, m)

	s.Require().NoError(err)

	s.Require().NotEmpty(res)
}
