package test

import (
	"github.com/golang/mock/gomock"
	extras "gitlab.mashroom.com/mashroom/backend/extras/api"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/model"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func (s *serviceSuite) TestExtrasUpdate_ok() {
	m := extras.UpdateRequest{
		ExtraService: &extras.Service{
			Id: &extras.Service_IdValue{
				IdValue: primitive.NewObjectID().Hex(),
			},
		},
		Placeholder: true,
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any())
	s.repo.EXPECT().ServiceUpdate(s.testCtx, gomock.Any())

	resp, err := s.srv.Update(s.testCtx, &m)

	s.Require().NoError(err)

	s.Require().Equal(resp.Success, true)
}

func (s *serviceSuite) TestExtrasUpdate_errCodeExist() {
	k := primitive.NewObjectID()
	m := extras.UpdateRequest{
		ExtraService: &extras.Service{
			Id: &extras.Service_IdValue{
				IdValue: k.Hex(),
			},
			Code: &extras.Service_CodeValue{
				CodeValue: k.String(),
			},
		},
		Placeholder: true,
	}

	s.repo.EXPECT().ServiceGetByID(s.testCtx, gomock.Any()).Return(&model.Service{
		Code: "hello",
	}, nil)
	s.repo.EXPECT().ServiceExistsByCode(s.testCtx, gomock.Any()).Return(true, nil)

	resp, err := s.srv.Update(s.testCtx, &m)

	s.Require().Errorf(err, "code already exist")

	s.Require().Nil(resp)
}

func (s *serviceSuite) TestExtrasUpdate_errInvalidHex() {
	m := extras.UpdateRequest{
		ExtraService: &extras.Service{
			Id: &extras.Service_IdValue{
				IdValue: "wrongID",
			},
		},
		Placeholder: true,
	}

	resp, err := s.srv.Update(s.testCtx, &m)

	s.Require().ErrorIs(err, primitive.ErrInvalidHex)

	s.Require().Nil(resp)
}
