package test

import (
	"context"
	"testing"

	"github.com/golang/mock/gomock"
	"github.com/stretchr/testify/suite"

	repo "gitlab.mashroom.com/mashroom/backend/extras/internal/model/mock"
	"gitlab.mashroom.com/mashroom/backend/extras/internal/service"
	mockoffer "gitlab.mashroom.com/mashroom/backend/offer/api/mock"
	mockproperty "gitlab.mashroom.com/mashroom/backend/property/api/mock"
)

type serviceSuite struct {
	suite.Suite
	srv                    service.Service
	rootCtx, testCtx       context.Context
	rootCancel, testCancel context.CancelFunc
	ctrl                   *gomock.Controller
	repo                   *repo.MockRepository
	property               *mockproperty.MockPropertyServiceClient
	offer                  *mockoffer.MockOfferServiceClient
}

func (s *serviceSuite) SetupSuite() {
	s.rootCtx, s.rootCancel = context.WithCancel(context.Background())
}

func (s *serviceSuite) SetupTest() {
	s.ctrl = gomock.NewController(s.T())
	s.repo = repo.NewMockRepository(s.ctrl)
	s.property = mockproperty.NewMockPropertyServiceClient(s.ctrl)
	s.offer = mockoffer.NewMockOfferServiceClient(s.ctrl)
	s.testCtx, s.testCancel = context.WithCancel(s.rootCtx)

	var err error

	s.srv, err = service.NewService(s.testCtx, &service.Config{
		Repository: s.repo,
		Connections: service.Connections{
			Property: s.property,
			Offer:    s.offer,
		},
	})
	s.Require().NoError(err)
}

func (s *serviceSuite) TearDownTest() {
	s.ctrl.Finish()

	s.testCancel()
}

func (s *serviceSuite) TearSuite() {
	s.rootCancel()
}

func TestService(t *testing.T) {
	suite.Run(t, &serviceSuite{})
}
